pub enum UnfinityMana {
Two,
Tap,
}Expand description
Kinds of mana only produced in unfinity
Variants
Two
Some sticker sheets have stickers that give creatures the ability to generate 2 colorless mana, for some reason wizards used the old templating
Examples
Tap
The is one unfinity card that produces this: Sole Performer