Module error

Module error 

This module exposes the possible errors this crate has, and ways to interact with them.

Structs

ScryfallError
An Error object represents a failure to find information or understand the input you provided to the API.

Enums

Error
The errors that may occur when interacting with the scryfall API.