pub struct Regex(pub String);Expand description
Regex is a newtype for String, indicating that the string represents a
regular expression and should be surrounded by slashes in the search
query.
For more information on supported regular expressions, see the official help page.
Example
let cards_named_fog = name(Regex::from(r"^fog$")).search_all().await?;
assert_eq!(cards_named_fog.len(), 1);
assert_eq!(cards_named_fog[0].name, "Fog");Tuple Fields
0: StringTrait Implementations
Sourceimpl ParamValue for Regex
impl ParamValue for Regex
impl Eq for Regex
impl StructuralPartialEq for Regex
impl TextOrRegexValue for Regex