pub trait BorderColorValue: ParamValue { }Expand description
A value representing a border color, such as black, white, or silver.
BorderColorValue is used as the argument type for border_color().
This trait is implemented for the BorderColor
and all TextValue types.