A List object represents a requested sequence of other objects (Cards,
Sets, etc). List objects may be paginated, and also include information
about issues raised when generating the list.
This module also defines ListIter, which can iterate over the contents
of a List. If the list is paginated, the ListIter will request each page
lazily.
Structs
- List
- A List object represents a requested sequence of other objects (Cards, Sets, etc). List objects may be paginated, and also include information about issues raised when generating the list.
- List
Iter - An iterator that moves objects out of a list.
- Page
Iter - An iterator over the pages of a list. Before returning each page, the next page is requested.